import { EMChatManagerListener, EMConversation, EMCursorResult, EMFetchMessageOption, EMGroupReadAck, EMMessage, EMConversationFilter, EMMessageBody, EMMessageReaction } from 'libhyphenate.so';
export class EMChatManager {
    sendMessage: (message: EMMessage) => void;
    sendReadAckForMessage: (message: EMMessage) => void;
    sendReadAckForConversation: (conversationId: string) => void;
    sendReadAckForGroupMessage: (message: EMMessage, ext: string) => void;
    recallMessage: (message: EMMessage, ext: string) => Promise<void>;
    resendMessage: (message: EMMessage) => void;
    modifyMessage: (messageId: string, body: EMMessageBody) => Promise<EMMessage>;
    downloadMessageThumbnail: (message: EMMessage) => void;
    downloadMessageAttachments: (message: EMMessage) => void;
    downloadAndParseCombineMessage: (message: EMMessage) => Promise<Array<EMMessage>>;
    pinMessage: (messageId: string) => Promise<void>;
    unpinMessage: (messageId: string) => Promise<void>;
    fetchPinnedMessagesFromServer: (conversationId: string) => Promise<Array<EMMessage>>;
    removeConversation: (conversationId: string, isRemoveMessages: boolean) => void;
    removeConversations: (list: Array<EMConversation>, isRemoveMessages: boolean) => void;
    conversationWithType: (conversationId: string, type: number, createIfNotExist: boolean) => EMConversation;
    getConversations: (isSort: boolean) => Array<EMConversation>;
    loadAllConversationsFromDB: (filter: (conversation: EMConversation) => boolean, clearCache: boolean) => Array<EMConversation>;
    addListener: (listener: EMChatManagerListener) => void;
    removeListener: (listener: EMChatManagerListener) => void;
    clearListeners: () => void;
    insertMessages: (list: Array<EMMessage>) => Promise<boolean>;
    fetchHistoryMessages: (conversationId: string, type: number, pageSize: number, cursor: string, fetchOption: EMFetchMessageOption) => Promise<EMCursorResult<EMMessage>>;
    getMessage: (messageId: string) => EMMessage;
    updateParticipant: (from: string, changeTo: string) => Promise<boolean>;
    uploadLog: () => Promise<void>;
    loadMoreMessageByKeywords: (timestamp: number, keyWords: string, count: number, from: string, direction: number) => Promise<Array<EMMessage>>;
    loadMoreMessageByType: (timestamp: number, type: number, count: number, from: string, direction: number) => Promise<Array<EMMessage>>;
    loadMoreMessageByTypes: (types: number, timestamp: number, count: number, from: string, direction: number) => Promise<Array<EMMessage>>;
    markAllConversationsAsRead: () => void;
    getDBMsgsCount: () => Promise<number>;
    fetchConversationsFromServer: (limit: number, cursor: string) => Promise<EMCursorResult<EMConversation>>;
    deleteConversationFromServer: (conversationId: string, type: number, isDeleteServerMessages: boolean) => Promise<void>;
    removeMessagesFromServer: (conversationId: string, conversationType: number, messages: Array<string>) => Promise<void>;
    removeMessagesFromServerByTimestamp: (conversationId: string, conversationType: number, beforeTimeStamp: number) => Promise<void>;
    fetchGroupReadAcks: (messageId: string, groupId: string, pageSize: number, startAckId: string) => Promise<EMCursorResult<EMGroupReadAck>>;
    // pin conversation
    pinConversation: (conversationId: string, isPinned: boolean) => Promise<void>;
    fetchPinnedConversationsFromServer: (limit: number, cursor: string) => Promise<EMCursorResult<EMConversation>>;
    getAllConversationsBySortFromDB: () => Array<EMConversation>;
    // conversation mark
    addConversationMark: (conversationIds: Array<string>, mark: number) => Promise<void>;
    removeConversationMark: (conversationIds: Array<string>, mark: number) => Promise<void>;
    fetchConversationsFromServerWithFilter: (cursor: string, filter: EMConversationFilter) => Promise<EMCursorResult<EMConversation>>;
    // reaction
    addReaction: (messageId: string, reaction: string) => Promise<void>;
    removeReaction: (messageId: string, reaction: string) => Promise<void>;
    fetchReactions: (messageId: Array<string>, chatType: number, groupId?: string) => Promise<Array<object>>;
    fetchReactionDetail: (messageId: string, reaction: string, pageSize: number, cursor: string) => Promise<EMMessageReaction>;
}
