import { EMGroup, EMError, EMGroupManagerListener, EMCursorResult, EMPageResult, EMMucSetting, EMStringCursorResult, EMCallback, EMMucSharedFile } from 'libhyphenate.so';
export class EMGroupManager {
    addListener: (listener: EMGroupManagerListener) => void;
    removeListener: (listener: EMGroupManagerListener) => void;
    clearListeners: () => void;
    groupWithId: (groupId: string) => EMGroup;
    allMyGroups: () => Promise<Array<EMGroup>>;
    loadAllMyGroupsFromDB: () => Promise<Array<EMGroup>>;
    fetchAllMyGroups: () => Promise<Array<EMGroup>>;
    fetchAllMyGroupsWithPage: (pageNum: number, pageSize: number, needMemberCount: boolean, needRole: boolean) => Promise<Array<EMGroup>>;
    fetchPublicGroupsWithCursor: (cursor: string, pageSize: number) => Promise<EMCursorResult<EMGroup>>;
    fetchPublicGroupsWithPage: (pageNum: number, pageSize: number, error: EMError) => EMPageResult;
    fetchJoinedGroupsCount: () => Promise<number>;
    createGroup: (groupName: string, desc: string, welcomeMessage: string, setting: EMMucSetting, allMembers: Array<string>) => Promise<EMGroup>;
    joinPublicGroup: (groupId: string) => Promise<EMGroup>;
    applyJoinPublicGroup: (groupId: string, nickName: string, message: string) => Promise<EMGroup>;
    ;
    leaveGroup: (groupId: string) => Promise<void>;
    destroyGroup: (groupId: string) => Promise<void>;
    addGroupMembers: (groupId: string, members: Array<string>, welcomeMessage: string) => Promise<EMGroup>;
    removeGroupMembers: (groupId: string, members: Array<string>) => Promise<EMGroup>;
    blockGroupMembers: (groupId: string, members: Array<string>, reason: string) => Promise<EMGroup>;
    unblockGroupMembers: (groupId: string, members: Array<string>) => Promise<EMGroup>;
    changeGroupSubject: (groupId: string, newSubject: string) => Promise<EMGroup>;
    changeGroupDescription: (groupId: string, newDescription: string) => Promise<EMGroup>;
    changeGroupExtension: (groupId: string, newExtension: string) => Promise<EMGroup>;
    fetchGroupSpecification: (groupId: string, fetchMembers: boolean) => Promise<EMGroup>;
    fetchGroupMembers: (groupId: string, cursor: string, pageSize: number) => Promise<EMStringCursorResult>;
    fetchGroupBans: (groupId: string, pageNum: number, pageSize: number) => Promise<Array<string>>;
    searchPublicGroup: (groupId: string) => Promise<EMGroup>;
    blockGroupMessage: (groupId: string) => Promise<EMGroup>;
    unblockGroupMessage: (groupId: string) => Promise<EMGroup>;
    acceptJoinGroupApplication: (groupId: string, user: string) => Promise<EMGroup>;
    declineJoinGroupApplication: (groupId: string, user: string, reason: string) => Promise<EMGroup>;
    acceptInvitationFromGroup: (groupId: string, inviter: string) => Promise<EMGroup>;
    declineInvitationFromGroup: (groupId: string, inviter: string, reason: string) => Promise<void>;
    transferGroupOwner: (groupId: string, newOwner: string) => Promise<EMGroup>;
    addGroupAdmin: (groupId: string, admin: string) => Promise<EMGroup>;
    removeGroupAdmin: (groupId: string, admin: string) => Promise<EMGroup>;
    muteGroupMembers: (groupId: string, members: Array<string>, muteDuration: number) => Promise<EMGroup>;
    unmuteGroupMembers: (groupId: string, members: Array<string>) => Promise<EMGroup>;
    fetchGroupMutes: (groupId: string, pageNum: number, pageSize: number) => Promise<Array<object>>;
    addToGroupWhiteList: (groupId: string, members: Array<string>) => Promise<void>;
    removeFromGroupWhiteList: (groupId: string, members: Array<string>) => Promise<void>;
    checkIfInGroupWhiteList: (groupId: string) => Promise<boolean>;
    fetchGroupWhiteList: (groupId: string) => Promise<Array<string>>;
    muteAllMembers: (groupId: string) => Promise<EMGroup>;
    unmuteAllMembers: (groupId: string) => Promise<EMGroup>;
    checkIfInGroupMutelist: (groupId: string) => Promise<boolean>;
    uploadGroupSharedFile: (groupId: string, filePath: string, callback: EMCallback) => Promise<EMMucSharedFile>;
    fetchGroupSharedFiles: (groupId: string, pageNum: number, pageSize: number) => Promise<Array<EMMucSharedFile>>;
    downloadGroupSharedFile: (groupId: string, fileId: string, savePath: string, callback: EMCallback) => Promise<void>;
    deleteGroupSharedFile: (groupId: string, fileId: string) => Promise<void>;
    fetchGroupAnnouncement: (groupId: string) => Promise<string>;
    updateGroupAnnouncement: (groupId: string, newAnnouncement: string) => Promise<EMGroup>;
    // 成员属性
    setMemberAttributes: (groupId: string, member: string, attributes: Map<string, string>) => Promise<void>;
    fetchMemberAttributes: (groupId: string, member: string) => Promise<Array<object>>;
    fetchMembersAttributes: (groupId: string, members: Array<string>, keys: Array<string>) => Promise<Array<object>>;
    clearAllLocalGroups: () => void;
}
